@@ -29,8 +29,8 @@ StartMenu & StartMenu::Instance() {
 
 
 const char *const menu_lines[] = {
-	"XGalaga++ v0.8.3 (2012-04-20)",
-	"2003-2009 Marc Mongenet, graphics from XGalaga 2.0.34",
+	"XGalaga++ v0.8.4 (2013-10-15)",
+	"2003-2013 Marc Mongenet, graphics from XGalaga 2.0.34",
 	"This game is free software, covered by the GPL.",
 	"",
 	"Welcome player %p!",
@@ -226,8 +226,8 @@ void StartMenu::PrintScores(XColor color)
 	     (look_for_player || pos.y < last_window_size_.y - LineHeight());
 	     ++it) {
 		++rank;
-		if (rank > scroll_scores_ &&
-		    !look_for_player || look_for_player && it->Name() == player_name) {
+		if ((rank > scroll_scores_ && !look_for_player) ||
+		    (look_for_player && it->Name() == player_name)) {
 			// Construct this line
 			ost.str("");
 			if (it->Value() != last_score) {
